@@ -57,6 +57,10 @@ class StatsFreeThrow(FreeThrow, StatsEnhancedPbpItem):
     def is_technical_ft(self):
         return " Technical" in self.description
 
+    @property
+    def is_flagrant_ft(self):
+        return " Flagrant" in self.description
+
     @property
     def is_ft_1pt(self):
         """
